==> zio-aws-appsync_2.13-7.21.15.4-sources.jar: zio/aws/appsync/model/ListTypesByAssociationRequest.scala <==
package zio.aws.appsync.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.appsync.model.primitives.{MaxResults, PaginationToken}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListTypesByAssociationRequest(
    mergedApiIdentifier: String,
    associationId: String,
    format: zio.aws.appsync.model.TypeDefinitionFormat,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest = {
    import ListTypesByAssociationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
      .builder()
      .mergedApiIdentifier(mergedApiIdentifier: java.lang.String)
      .associationId(associationId: java.lang.String)
      .format(format.unwrap)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.ListTypesByAssociationRequest.ReadOnly =
    zio.aws.appsync.model.ListTypesByAssociationRequest.wrap(buildAwsValue())
}
object ListTypesByAssociationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.ListTypesByAssociationRequest =
      zio.aws.appsync.model.ListTypesByAssociationRequest(
        mergedApiIdentifier,
        associationId,
        format,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def mergedApiIdentifier: String
    def associationId: String
    def format: zio.aws.appsync.model.TypeDefinitionFormat
    def nextToken: Optional[PaginationToken]
    def maxResults: Optional[MaxResults]
    def getMergedApiIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(mergedApiIdentifier)
    def getAssociationId: ZIO[Any, Nothing, String] = ZIO.succeed(associationId)
    def getFormat
        : ZIO[Any, Nothing, zio.aws.appsync.model.TypeDefinitionFormat] =
      ZIO.succeed(format)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
  ) extends zio.aws.appsync.model.ListTypesByAssociationRequest.ReadOnly {
    override val mergedApiIdentifier: String =
      impl.mergedApiIdentifier(): String
    override val associationId: String = impl.associationId(): String
    override val format: zio.aws.appsync.model.TypeDefinitionFormat =
      zio.aws.appsync.model.TypeDefinitionFormat.wrap(impl.format())
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.appsync.model.primitives.PaginationToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.appsync.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
  ): zio.aws.appsync.model.ListTypesByAssociationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appsync_3-6.20.120.1-sources.jar: zio/aws/appsync/model/ListTypesByAssociationRequest.scala <==
package zio.aws.appsync.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.appsync.model.primitives.{MaxResults, PaginationToken}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListTypesByAssociationRequest(
    mergedApiIdentifier: String,
    associationId: String,
    format: zio.aws.appsync.model.TypeDefinitionFormat,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest = {
    import ListTypesByAssociationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
      .builder()
      .mergedApiIdentifier(mergedApiIdentifier: java.lang.String)
      .associationId(associationId: java.lang.String)
      .format(format.unwrap)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.ListTypesByAssociationRequest.ReadOnly =
    zio.aws.appsync.model.ListTypesByAssociationRequest.wrap(buildAwsValue())
}
object ListTypesByAssociationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.ListTypesByAssociationRequest =
      zio.aws.appsync.model.ListTypesByAssociationRequest(
        mergedApiIdentifier,
        associationId,
        format,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def mergedApiIdentifier: String
    def associationId: String
    def format: zio.aws.appsync.model.TypeDefinitionFormat
    def nextToken: Optional[PaginationToken]
    def maxResults: Optional[MaxResults]
    def getMergedApiIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(mergedApiIdentifier)
    def getAssociationId: ZIO[Any, Nothing, String] = ZIO.succeed(associationId)
    def getFormat
        : ZIO[Any, Nothing, zio.aws.appsync.model.TypeDefinitionFormat] =
      ZIO.succeed(format)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
  ) extends zio.aws.appsync.model.ListTypesByAssociationRequest.ReadOnly {
    override val mergedApiIdentifier: String =
      impl.mergedApiIdentifier(): String
    override val associationId: String = impl.associationId(): String
    override val format: zio.aws.appsync.model.TypeDefinitionFormat =
      zio.aws.appsync.model.TypeDefinitionFormat.wrap(impl.format())
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.appsync.model.primitives.PaginationToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.appsync.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.ListTypesByAssociationRequest
  ): zio.aws.appsync.model.ListTypesByAssociationRequest.ReadOnly = new Wrapper(
    impl
  )
}
